@@ -1,9 +1,9 @@
 package Sah::Schema::color::ansi16;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = [str => {
     summary => 'ANSI-16 color, either a number from 0-15 or color names like "black", "bold red", etc',
@@ -33,7 +33,7 @@ Sah::Schema::color::ansi16 - ANSI-16 color, either a number from 0-15 or color n
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::color::ansi16 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
+This document describes version 0.012 of Sah::Schema::color::ansi16 (from Perl distribution Sah-Schemas-Color), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -69,15 +69,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ 0  # valid
 
- undef  # valid
+ 15  # valid
 
- undef  # INVALID
+ 16  # INVALID
 
- undef  # valid
+ "black"  # valid, becomes "black"
 
- undef  # INVALID
+ "foo"  # INVALID
 
 =head1 HOMEPAGE
 
