@@ -1,9 +1,9 @@
 package Sah::Schema::color::rgb24;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
@@ -34,7 +34,7 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
+This document describes version 0.012 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -70,15 +70,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ "000000"  # valid, becomes "000000"
 
- undef  # valid
+ "black"  # valid, becomes "000000"
 
- undef  # valid
+ "FFffcc"  # valid, becomes "ffffcc"
 
- undef  # valid
+ "#FFffcc"  # valid, becomes "ffffcc"
 
- undef  # INVALID
+ "foo"  # INVALID
 
 =head1 DESCRIPTION
 
